@@ -62,6 +62,19 @@ T = TypeVar("T")
 
 
 def is_path(maybe_path: Any) -> bool:
+    """
+    >>> is_path("str")
+    False
+
+    >>> is_path((1, (), 0))
+    False
+
+    >>> is_path((1, 2, 0))
+    True
+
+    :param maybe_path: Element to check for being a `Path`.
+    :return: Returns `True` if `maybe_path` is a `Path`.
+    """
     return isinstance(maybe_path, tuple) and all(
         isinstance(elem, int) for elem in maybe_path
     )
@@ -261,13 +274,11 @@ def cluster_by_common_elements(
     Clusters elements of l by shared elements. Elements of interest are obtained using f.
     For instance, to cluster a list of lists based on common list elements:
 
-    >>> cluster_by_common_elements([[1,2], [2,3], [3,4], [5,6]], lambda l: {e for e in a_list})
-
-    Gives [[[2, 3], [3, 4], [1, 2]], [[5, 6]]].
+    >>> cluster_by_common_elements([[1,2], [2,3], [3,4], [5,6]], lambda l: {e for e in l})
+    [[[2, 3], [3, 4], [1, 2]], [[5, 6]]]
 
     >>> cluster_by_common_elements([1,2,3,4,5,6,7], lambda e: {e, e+3})
-
-    Outputs [[2, 5], [3, 6], [4, 7, 1]].
+    [[2, 5], [3, 6], [4, 7, 1]]
 
     :param a_list: The list to cluster.
     :param f: The function to determine commonality.
@@ -919,3 +930,25 @@ def compute_nullable_nonterminals(canonical_grammar: CanonicalGrammar) -> Set[st
                 result.add(nonterminal)
 
     return result
+
+
+def merge_dict_of_sets(
+    dict_1: Dict[T, Set[S]], dict_2: Dict[T, Set[S]]
+) -> Dict[T, Set[S]]:
+    """
+    Merges the given dictionaries.
+
+    >>> dict_1 = {1: {2}, 2: {3}, 3: set()}
+    >>> dict_2 = {1: {42}, 3: {17}, 4: {5, 6}}
+    >>> merge_dict_of_sets(dict_1, dict_2)
+    {1: {2, 42}, 2: {3}, 3: {17}, 4: {5, 6}}
+
+    :param dict_1: First dict to merge.
+    :param dict_2: Second dict to merge.
+    :return: The merged dictionary.
+    """
+    result = {**dict_1, **dict_2}
+    for key in result:
+        if key in dict_1 and key in dict_2:
+            result[key] = dict_1[key] | dict_2[key]
+    return result
